check_freq_input — pysm v3.0.0

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.0.0 »
- pysm Documentation »
- check_freq_input

# check_freq_input

`pysm.` `check_freq_input`(freqs)

  Function to check that the input to `Model.get_emission` is a np.ndarray.

  This function will convet input integers or arrays to a single element numpy array.

  Parameters
    freqs: int, float, list, ndarray
  Returns
    ndarray

      Frequencies in numpy array form.